package com.dgtly.goods.service.impl;

import java.util.List;
import com.dgtly.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.dgtly.goods.mapper.GoodsTypeMapper;
import com.dgtly.goods.domain.GoodsType;
import com.dgtly.goods.service.IGoodsTypeService;
import com.dgtly.common.core.text.Convert;

/**
 * 商品分类列Service业务层处理
 * 
 * @author dgtly
 * @date 2020-02-13
 */
@Service
public class GoodsTypeServiceImpl implements IGoodsTypeService 
{
    @Autowired
    private GoodsTypeMapper goodsTypeMapper;

    /**
     * 查询商品分类列
     * 
     * @param id 商品分类列ID
     * @return 商品分类列
     */
    @Override
    public GoodsType selectGoodsTypeById(Long id)
    {
        return goodsTypeMapper.selectGoodsTypeById(id);
    }

    /**
     * 查询商品分类列列表
     * 
     * @param goodsType 商品分类列
     * @return 商品分类列
     */
    @Override
    public List<GoodsType> selectGoodsTypeList(GoodsType goodsType)
    {
        return goodsTypeMapper.selectGoodsTypeList(goodsType);
    }

    /**
     * 新增商品分类列
     * 
     * @param goodsType 商品分类列
     * @return 结果
     */
    @Override
    public int insertGoodsType(GoodsType goodsType)
    {
        goodsType.setCreateTime(DateUtils.getNowDate());
        return goodsTypeMapper.insertGoodsType(goodsType);
    }

    /**
     * 修改商品分类列
     * 
     * @param goodsType 商品分类列
     * @return 结果
     */
    @Override
    public int updateGoodsType(GoodsType goodsType)
    {
        goodsType.setUpdateTime(DateUtils.getNowDate());
        return goodsTypeMapper.updateGoodsType(goodsType);
    }

    /**
     * 删除商品分类列对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteGoodsTypeByIds(String ids)
    {
        return goodsTypeMapper.deleteGoodsTypeByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除商品分类列信息
     * 
     * @param id 商品分类列ID
     * @return 结果
     */
    @Override
    public int deleteGoodsTypeById(Long id)
    {
        return goodsTypeMapper.deleteGoodsTypeById(id);
    }
}
